;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "dim-autoload" "20251101.2000"
  "Dim or hide autoload cookie lines."
  '((emacs  "26.1")
    (compat "30.1"))
  :url "https://github.com/tarsius/dim-autoload"
  :commit "793b259f6ad2c1b47152986ec2d39622792fb3d2"
  :revdesc "793b259f6ad2"
  :keywords '("convenience")
  :authors '(("Jonas Bernoulli" . "emacs.dim-autoload@jonas.bernoulli.dev"))
  :maintainers '(("Jonas Bernoulli" . "emacs.dim-autoload@jonas.bernoulli.dev")))
